@@ -24,7 +24,7 @@ async def get_bus_names():
 	:return:
 	:rtype:
 	"""
-	bus = await hub.SESSION_BUS
+	bus = hub.SESSION_BUS
 	reply = await bus.call(
 		Message(
 			destination="org.freedesktop.DBus",
@@ -41,7 +41,7 @@ async def pause_media_playback():
 	Before going to sleep, it's a good idea to pause media playback. This will pause music playback as well as things
 	like YouTube videos. Idled takes care of this directly in the user's session, by using this method.
 	"""
-	bus = await hub.SESSION_BUS
+	bus = hub.SESSION_BUS
 	for bus_name in await get_bus_names():
 		if bus_name.startswith("org.mpris.MediaPlayer2."):
 			introspection = await bus.introspect(bus_name, "/org/mpris/MediaPlayer2")
@@ -63,7 +63,7 @@ async def get_session_inhibitor(inhibitor_obj_path):
 	         find an idle or sleep inhibitor. We will return None, None if nothing we are interested in is found.
 	:rtype: tuple
 	"""
-	bus = await hub.SESSION_BUS
+	bus = hub.SESSION_BUS
 	bus_name = "org.gnome.SessionManager"
 	introspection = await bus.introspect(bus_name, inhibitor_obj_path)
 	obj = bus.get_proxy_object(bus_name, inhibitor_obj_path, introspection)
@@ -85,7 +85,7 @@ async def get_session_inhibitors():
 
 	There are also lower-level logind inhibitors, which are handled by powerbus, not idled.
 	"""
-	bus = await hub.SESSION_BUS
+	bus = hub.SESSION_BUS
 	bus_name = "org.gnome.SessionManager"
 	path = "/" + bus_name.replace(".", "/")
 	introspection = await bus.introspect(bus_name, path)
@@ -108,7 +108,7 @@ async def lock_screensaver():
 	"""
 	This method is used by idled to find a screensaver and activate its screen lock.
 	"""
-	bus = await hub.SESSION_BUS
+	bus = hub.SESSION_BUS
 	screensaver_list = [
 		"org.gnome.ScreenSaver",
 		"org.cinnamon.ScreenSaver",
